@@ -9,7 +9,7 @@ use IUP::Internal::LibraryIup;
 use IUP::Constants;
 
 # following recommendation from http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.101";
+our $VERSION = "0.201";
 $VERSION = eval $VERSION;
 
 sub BEGIN {
@@ -30,10 +30,10 @@ sub import {
 
   my %tags = (
      #UPDATE when element list change
-     ':basic' => [qw/Constants Button Cbox Clipboard ColorBar ColorBrowser ColorDlg Dial Dialog FileDlg Fill FontDlg Frame
-                     Hbox Image Item Label List Menu MessageDlg Normalizer ProgressBar Radio 
+     ':basic' => [qw/Constants Button Cbox Clipboard ColorBar ColorBrowser ColorDlg ProgressDlg Dial Dialog FileDlg Fill FontDlg Frame
+                     Hbox Image Item Label List Menu MessageDlg Normalizer ProgressBar Radio Expander ScrollBox Link GridBox 
                      Sbox Separator Spin SpinBox Split Submenu Tabs Text Timer Toggle Tree User Val Vbox Zbox/], 
-     ':extended' => [qw/Matrix Cells Canvas CanvasGL PPlot LayoutDialog ElementPropertiesDialog/],
+     ':extended' => [qw/Matrix MatrixList Cells Canvas CanvasGL PPlot MglPlot LayoutDialog ElementPropertiesDialog Gauge/],
      ':all' => [],
   );  
   @{$tags{':all'}} = ( @{$tags{':basic'}}, @{$tags{':extended'}} );
@@ -206,6 +206,14 @@ sub GetByIhandle {
     val          => "IUP::Val",
     vbox         => "IUP::Vbox",
     zbox         => "IUP::Zbox",  
+    mglplot      => 'IUP::MglPlot',
+    matrixlist   => 'IUP::MatrixList',
+    expander     => 'IUP::Expander',
+    link         => 'IUP::Link',
+    gridbox      => 'IUP::GridBox',
+    gauge        => 'IUP::Gauge',
+    progressdlg  => 'IUP::ProgressDlg',
+    scrollbox    => 'IUP::ScrollBox',
   };
   return unless $ih;
   my $e = IUP::Internal::LibraryIup::_translate_ih($ih);
@@ -428,12 +436,6 @@ sub isCtrlXkey  { shift; return IUP::Internal::LibraryIup::_isCtrlXkey(@_); };
 sub isAltXkey   { shift; return IUP::Internal::LibraryIup::_isAltXkey(@_); };
 sub isSysXkey   { shift; return IUP::Internal::LibraryIup::_isSysXkey(@_); };
 sub isPrintable { shift; return IUP::Internal::LibraryIup::_isPrintable(@_); };
-#xxxCHECKLATER
-#sub xCODE       { shift; return IUP::Internal::LibraryIup::_xCODE(@_); };
-#sub sxCODE      { shift; return IUP::Internal::LibraryIup::_sxCODE(@_); };
-#sub cxCODE      { shift; return IUP::Internal::LibraryIup::_cxCODE(@_); };
-#sub mxCODE      { shift; return IUP::Internal::LibraryIup::_mxCODE(@_); };
-#sub yxCODE      { shift; return IUP::Internal::LibraryIup::_yxCODE(@_); };
 
 #### mouse related macros
 sub isShift     { shift; return IUP::Internal::LibraryIup::_isShift(@_); };
